@@ -35,11 +35,14 @@ class TaskValidator(MapBuilder):
             target=task_validation,
             projection=[
                 "orig_inputs",
+                "input.hubbards",
                 "output.structure",
                 "output.bandgap",
-                "calcs_reversed.input.parameters",
                 "calcs_reversed.output.ionic_steps.electronic_steps.e_fr_energy",
                 "tags",
+                # Need these two for proper run_type determination
+                "calcs_reversed.input.parameters",
+                "calcs_reversed.input.incar",
             ],
             query=query,
             **kwargs,
